SystemOrganization addCategory: #ConfigurationOfCoral!

Object subclass: #ConfigurationOfCoral
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCoral'!

!ConfigurationOfCoral commentStamp: 'DamienPollet 8/13/2011 01:44' prior: 0!
Coral makes it possible to write shell scripts with Pharo.

Recommended loading:
	ConfigurationOfCoral load.             "as a user"
	ConfigurationOfCoral loadBleedingEdge. "as a contributor"
	

Development workflow	scripts

	MetacelloToolBox
		createDevelopment: '0.1'
		for: 'ConfigurationOfCoral'
		importFromBaseline: '0.1-baseline'
		description: 'Initial development version'.

	MetacelloToolBox validateConfiguration: ConfigurationOfCoral.

	Gofer new squeaksource: 'Coral';
		package: 'ConfigurationOfCoral';
		package: 'Coral-Core';
		package: 'Coral-Commandline';
		package: 'Coral-Tests';
		package: 'Coral-Utilities';
		commit: 'Reorganize packages, rewrite ConfigurationOfCoral from scratch.'
!

!ConfigurationOfCoral class methodsFor: 'development support' stamp: 'DamienPollet 8/13/2011 01:12'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfCoral class methodsFor: 'private' stamp: 'DamienPollet 8/13/2011 01:12'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfCoral class methodsFor: 'private' stamp: 'DamienPollet 8/13/2011 01:12'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfCoral class methodsFor: 'private' stamp: 'DamienPollet 8/13/2011 01:12'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfCoral class methodsFor: 'metacello tool support' stamp: 'DamienPollet 8/13/2011 01:12'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCoral class methodsFor: 'loading' stamp: 'DamienPollet 8/13/2011 01:12'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfCoral class methodsFor: 'loading' stamp: 'DamienPollet 8/13/2011 01:12'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfCoral class methodsFor: 'loading' stamp: 'DamienPollet 8/13/2011 01:12'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfCoral class methodsFor: 'accessing' stamp: 'DamienPollet 8/13/2011 01:12'!
project

	^self new project! !

!ConfigurationOfCoral class methodsFor: 'development support' stamp: 'DamienPollet 8/13/2011 01:12'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfCoral methodsFor: 'baselines' stamp: 'DamienPollet 8/13/2011 01:34'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Coral'.
		
		spec
			project: 'Filesystem' with: [
				spec
					className: 'ConfigurationOfFilesystem';
					versionString: #bleedingEdge;
					repository: 'http://www.squeaksource.com/fs' ];
			project: 'OSProcess' with: [
				spec
					className: 'ConfigurationOfOSProcess';
					versionString: #stable;
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'PetitParser' with: [
				spec
					className: 'ConfigurationOfPetitParser';
					versionString: #bleedingEdge;
					loads: #('Core' 'Tests' 'PetitSmalltalk');
					repository: 'http://source.lukas-renggli.ch/petit' ].

		spec
			package: 'Coral-Core' with: [
				spec requires: #('PetitParser' 'OSProcess' ). ];
			package: 'Coral-Utilities' with: [
				spec requires: #('Filesystem' 'OSProcess' ). ];
			package: 'Coral-Commandline' with: [
				spec requires: #('PetitParser' ). ];
			package: 'Coral-Tests' with: [
				spec requires: #('Coral-Core' 'Coral-Commandline' ). ].
		spec
			group: 'default' with: #('Coral-Core' 'Coral-Utilities' 'Coral-Commandline' );
			group: 'tests' with: #('Coral-Tests' 'OSProcess-Tests'). ].
! !

!ConfigurationOfCoral methodsFor: 'accessing' stamp: 'DamienPollet 8/13/2011 01:12'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

Object subclass: #OldConfigurationOfCoral
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCoral'!

!OldConfigurationOfCoral commentStamp: 'DamienPollet 8/7/2011 22:03' prior: 0!
Recommended loading:

	"Loads most recent commits according to the baseline."
	ConfigurationOfCoral project bleedingEdge load.
	
	"Coral is still under development, so the symbolic version 'default' loads the same as #bleedingEdge."
	(ConfigurationOfCoral project version: 'default') load
	!

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 16:59'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
load
	"self load"

	^self project latestVersion load! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!OldConfigurationOfCoral class methodsFor: 'as yet unclassified' stamp: 'StephaneDucasse 6/29/2010 17:00'!
project

	^self new project! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/7/2011 02:52'!
baseline01: spec 
	<version: '0.1-baseline'>
	spec for: #common do: [ 
			spec blessing: #baseline.
			
			spec package: 'Filesystem' with: [
				spec repository: 'http://source.wiresong.ca/mc'. 	
			].
				
			spec package: 'AST-Core' with: [
				spec repository: 'http://www.squeaksource.com/rb'. 
			].
			
			spec package: 'OSProcess' with: [
				spec repository: 'http://www.squeaksource.com/OSProcess'. 
			].
			
			spec package: 'OSProcess-Tests' with: [
				spec repository: 'http://www.squeaksource.com/OSProcess';
					requires: 'OSProcess'
			].
	
			spec repository: 'http://source.lukas-renggli.ch/petit'.
			
			spec package: 'PetitParser' with: [
				spec requires: #('AST-Core') 
			].	
			
			spec package: 'PetitSmalltalk' with: [
				spec requires: #('PetitParser') 
			].
		
			spec package: 'PetitTest' with: [
				spec requires: #('PetitParser') 
			].
			
			spec repository: 'http://www.squeaksource.com/Coral'.
			spec package:  'Coral' with: [
				spec requires: #( 'Filesystem' 'OSProcess' 'PetitSmalltalk' )	
			].
		
			spec
				group: 'default' with: #('Coral' );
				group: 'tests' with: #( 'Coral' 'PetitTest' 'OSProcess-Tests' ).
		]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/7/2011 02:52'!
baseline02: spec 
	<version: '0.2-baseline'>
	spec for: #common do: [ 
			spec blessing: #baseline.
			
			spec package: 'Filesystem' with: [
				spec repository: 'http://www.squeaksource.com/fs'. 	
			].
				
			spec package: 'AST-Core' with: [
				spec repository: 'http://www.squeaksource.com/rb'. 
			].
			
			spec package: 'OSProcess' with: [
				spec repository: 'http://www.squeaksource.com/OSProcess'. 
			].
			
			spec package: 'OSProcess-Tests' with: [
				spec repository: 'http://www.squeaksource.com/OSProcess';
					requires: 'OSProcess'
			].
	
			spec repository: 'http://source.lukas-renggli.ch/petit'.
			
			spec package: 'PetitParser' with: [
				spec requires: #('AST-Core') 
			].	
			
			spec package: 'PetitSmalltalk' with: [
				spec requires: #('PetitParser') 
			].
		
			spec package: 'PetitTest' with: [
				spec requires: #('PetitParser') 
			].
			
			spec repository: 'http://www.squeaksource.com/Coral'.
			spec package:  'Coral' with: [
				spec requires: #( 'Filesystem' 'OSProcess' 'PetitSmalltalk' )	
			].
		
			spec
				group: 'default' with: #('Coral' );
				group: 'tests' with: #( 'Coral' 'PetitTest' 'OSProcess-Tests' ).
		]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/7/2011 02:52'!
baseline03: spec 
	<version: '0.3-baseline'>
	spec for: #common do: [ 
			spec blessing: #baseline.
			
			spec package: 'Filesystem' with: [
				spec repository: 'http://www.squeaksource.com/fs'. 	
			].
				
			spec package: 'AST-Core' with: [
				spec repository: 'http://www.squeaksource.com/rb'. 
			].
			
			spec project: 'OSProcess' with: [
				spec
					className: 'ConfigurationOfOSProcess';
					file: 'ConfigurationOfOSProcess';
					version: '4.4.2';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		
	
			spec repository: 'http://source.lukas-renggli.ch/petit'.
			
			spec package: 'PetitParser' with: [
				spec requires: #('AST-Core') 
			].	
			
			spec package: 'PetitSmalltalk' with: [
				spec requires: #('PetitParser' 'PetitTest') 
			].
		
			spec package: 'PetitTest' with: [
				spec requires: #('PetitParser') 
			].
			
			spec repository: 'http://www.squeaksource.com/Coral'.
			spec package:  'Coral' with: [
				spec requires: #( 'Filesystem' 'OSProcess' 'PetitSmalltalk' )	
			].
		
			spec
				group: 'default' with: #('Coral' );
				group: 'tests' with: #( 'Coral' 'PetitTest' 'OSProcess-Tests' ).
		]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/12/2011 18:12'!
baseline04: spec 
	<version: '0.4-baseline'>
	spec for: #common do: [ 
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/Coral'.
		
		spec project: 'Filesystem' with: [
			spec repository: 'http://www.squeaksource.com/fs';
				className: 'ConfigurationOfFilesystem' ].
		
		spec project: 'OSProcess' with: [
			spec repository: 'http://www.squeaksource.com/MetacelloRepository';
				className: 'ConfigurationOfOSProcess' ].
	
		spec project: 'PetitParser' with: [
			spec repository: 'http://source.lukas-renggli.ch/petit';
				className: 'ConfigurationOfPetitParser';
				versionString: #bleedingEdge;
				loads: #('Core' 'PetitTests' 'PetitSmalltalk') ].
		
		spec
			package:  'Coral' with: [
				spec requires: #( 'Filesystem' 'OSProcess' 'PetitParser' ) ].
		
		spec
			group: 'default' with: #( 'Coral' );
			group: 'tests' with: #( 'Coral' 'OSProcess-Tests' ).
	]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/7/2011 03:26'!
default: spec 
	<symbolicVersion: 'default'>
	
	spec for: #common version: '0.4-baseline'! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'StephaneDucasse 6/29/2010 17:08'!
project
 
	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/11/2011 23:43'!
version01: spec 
	<version: '0.1'>
	spec for: #common do: [
		spec blessing: #development.
			spec repository: 'http://source.wiresong.ca/mc'. 
			spec package: 'Filesystem'.
				
			spec repository: 'http://www.squeaksource.com/rb'. 
			spec package: 'AST-Core' with: 'AST-Core-lr.79'.
			
			spec repository: 'http://www.squeaksource.com/OSProcess'. 
			spec package: 'OSProcess'.
			
			spec repository: 'http://source.lukas-renggli.ch/petit'.
				spec package: 'PetitParser' with: 'PetitParser-lr.122'.	
				spec package: 'PetitSmaltalk' with: 'PetitSmalltalk-lr.13'.
			
			spec repository: 'http://www.squeaksource.com/Coral'.
			spec package:  'Coral'.
		]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/11/2011 23:43'!
version02: spec 
	<version: '0.2'>
	"trying to load latest AST and petitParser/petitSmalltalk"
	spec for: #common do: [
		spec blessing: #development.
			spec repository: 'http://source.wiresong.ca/mc'. 
			spec package: 'Filesystem'.
				
			spec repository: 'http://www.squeaksource.com/rb'. 
			spec package: 'AST-Core' with: 'AST-Core-lr.86'.
			
			spec repository: 'http://www.squeaksource.com/OSProcess'. 
			spec package: 'OSProcess'.
			
			spec repository: 'http://source.lukas-renggli.ch/petit'.
				spec package: 'PetitParser' with: 'PetitParser-lr.205'.		
				spec package: 'PetitTest' with: 'PetitTests-lr.21'.	
				spec package: 'PetitSmaltalk' with: 'PetitSmalltalk-lr.44'.
			
			spec repository: 'http://www.squeaksource.com/Coral'.
			spec package:  'Coral'.
		]! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/11/2011 23:43'!
version03: spec 
	<version: '0.3' imports: #('0.3-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec 
			package: 'Filesystem' with: 'Filesystem-DamienPollet.114';
			package: 'OSProcess' with: 'OSProcess-dtl.59';
			package: 'AST-Core' with: 'AST-Core-lr.87';
			package: 'PetitParser' with: 'PetitParser-TudorGirba.209';		
			package: 'PetitTest' with: 'PetitTests-TudorGirba.28';	
			package: 'OSProcess' with: 'OSProcess-Tests-dtl.4';
			package: 'PetitSmaltalk' with: 'PetitSmalltalk-lr.46'.]
		! !

!OldConfigurationOfCoral methodsFor: 'versions' stamp: 'DamienPollet 8/11/2011 23:43'!
version04: spec 
	<version: '0.4' imports: #('0.4-baseline')>

	spec for: #'common' do: [
		spec blessing: #development.
		spec
			project: 'Filesystem' with: '2.0.1';
			project: 'OSProcess' with: '4.4.2';
			project: 'PetitParser' with: '1.4'. ]! !
